﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using HeuristicLab.Core;
using HeuristicLab.Hive.Slave.Console.SlaveConsoleService;
using HeuristicLab.Clients.Common;

namespace HeuristicLab.Hive.Slave.Console {
  internal class LogServiceReader : ILogReader {

    private Timer timer;
    private int messageCount = 0;

    public LogServiceReader() {
    }

    public void Start() {
      timer = new Timer();
      timer.Interval = 2000;
      timer.Tick += new EventHandler(timer_Tick);
      timer.Start();
    }

    void timer_Tick(object sender, EventArgs e) {
      try {
        using (var slaveClient = ClientFactory.CreateClient<ISlaveConsoleCommunicator>("SlaveConsoleTcpEndpointClient")) {
          try {
            var messages = slaveClient.Obj.GetLogMessages();
            if (messages.Count < messageCount) {
              messageCount = 0; // log got cleared
            }
            var newMessages = messages.GetRange(messageCount, messages.Count - messageCount);
            messageCount = messages.Count;
            OnMoreData(newMessages);

          }
          catch (Exception ex) {
            OnMoreData(new List<string> { "Error fetching log: " + ex.ToString() });
          }
        }
      }
      catch (Exception ex) {
        OnMoreData(new List<string> { "Error in slave-communication: " + ex.ToString() });
      }
    }

    public void Stop() {
      timer.Stop();
    }

    public event MoreDataHandler MoreData;
    private void OnMoreData(IEnumerable<string> newMessages) {
      var handler = MoreData;
      var newData = string.Join(Environment.NewLine, newMessages.ToArray());
      if (newMessages.Count() > 0) newData += Environment.NewLine;
      if (handler != null) MoreData(this, newData);
    }
  }
}
